@@ -1,8 +1,7 @@
-from typing import Optional
 
-def fib_recurring(number: int) -> Optional[int]:
+def fib_recurring(number: int) -> int:
     if number < 0:
-        return None
+        raise ValueError("Fibonacci has to be equal or above zero")
     elif number <= 1:
         return number
     else:
