@@ -8,7 +8,9 @@ class RecurringFibNumberTest(TestCase):
         self.assertEqual(0, fib_recurring(0))
 
     def test_negative(self):
-        self.assertEqual(None, fib_recurring(-1))
+        with self.assertRaises(ValueError) as raised_err:
+            fib_recurring(-1)
+            self.assertEqual("Fibonacci has to be equal or above zero", str(raised_err))
 
     def test_one(self):
         self.assertEqual(1, fib_recurring(1))
